@@ -1,7 +1,10 @@
 import logging
+import os
+
 import boto3
 from botocore.exceptions import ClientError
-import os
+
+from src.model.file_path import FilePath
 
 
 class S3Service:
@@ -15,15 +18,15 @@ class S3Service:
             raise Exception("Please set AWS_DEFAULT_REGION")
         self.bucket = bucket
 
-    def upload_file(self, file_name, object_name=None):
+    def upload_file(self, file_path: FilePath, object_name=None):
         # If S3 object_name was not specified, use file_name
         if object_name is None:
-            object_name = os.path.basename(file_name)
+            object_name = file_path.get_base_name()
 
         # Upload the file
         s3_client = boto3.client('s3')
         try:
-            response = s3_client.upload_file(file_name, self.bucket, object_name)
+            response = s3_client.upload_file(file_path.value, self.bucket, object_name)
         except ClientError as e:
             logging.error(e)
             return False
